@@ -18,9 +18,10 @@ mod transfers;
 use crate::client::{config_handler::Config, connections::Session, errors::Error};
 use crate::messaging::client::{Cmd, CmdError, DataCmd, Error as ErrorMessage, TransferCmd};
 use crate::transfers::TransferActor;
-use crate::types::{Keypair, PublicKey, SectionElders, Token};
+use crate::types::{Chunk, ChunkAddress, Keypair, PublicKey, SectionElders, Token};
 use crdts::Dot;
 use log::{debug, info, trace, warn};
+use lru::LruCache;
 use rand::rngs::OsRng;
 use std::{
     path::Path,
@@ -28,11 +29,12 @@ use std::{
     {collections::HashSet, net::SocketAddr, sync::Arc},
 };
 use tokio::sync::mpsc::Receiver;
-use tokio::sync::RwLock;
+use tokio::sync::{Mutex, RwLock};
 use tokio::time::Duration;
 
 // Number of attempts to make when trying to bootstrap to the network
 const NUM_OF_BOOTSTRAPPING_ATTEMPTS: u8 = 1;
+const BLOB_CACHE_CAP: usize = 150;
 
 /// Client object
 #[derive(Clone, Debug)]
@@ -42,6 +44,7 @@ pub struct Client {
     simulated_farming_payout_dot: Dot<PublicKey>,
     incoming_errors: Arc<RwLock<Receiver<CmdError>>>,
     session: Session,
+    blob_cache: Arc<Mutex<LruCache<ChunkAddress, Chunk>>>,
     pub(crate) query_timeout: Duration,
 }
 
@@ -148,6 +151,7 @@ impl Client {
             session,
             incoming_errors: Arc::new(RwLock::new(err_receiver)),
             query_timeout: Duration::from_secs(query_timeout),
+            blob_cache: Arc::new(Mutex::new(LruCache::new(BLOB_CACHE_CAP))),
         };
 
         Self::handle_anti_entropy_errors(client.clone(), transfer_err_receiver);
@@ -303,7 +307,7 @@ mod tests {
 
     #[tokio::test]
     pub async fn client_creation() -> Result<()> {
-        let _client = create_test_client().await?;
+        let _client = create_test_client(None).await?;
 
         Ok(())
     }
@@ -327,7 +331,7 @@ mod tests {
         let full_id = Keypair::new_ed25519(&mut rng);
         let pk = full_id.public_key();
 
-        let client = create_test_client_with(Some(full_id)).await?;
+        let client = create_test_client_with(Some(full_id), None).await?;
         assert_eq!(pk, client.public_key());
 
         Ok(())
@@ -335,7 +339,7 @@ mod tests {
 
     #[tokio::test]
     pub async fn long_lived_connection_survives() -> Result<()> {
-        let client = create_test_client().await?;
+        let client = create_test_client(None).await?;
         tokio::time::sleep(tokio::time::Duration::from_secs(40)).await;
         let balance = client.get_balance().await?;
         assert_ne!(balance, Token::from_nano(0));
