@@ -260,7 +260,7 @@ mod tests {
 
     #[tokio::test]
     pub async fn register_basics() -> Result<()> {
-        let client = create_test_client().await?;
+        let client = create_test_client(None).await?;
 
         let name = XorName(rand::random());
         let tag = 15000;
@@ -301,7 +301,7 @@ mod tests {
 
     #[tokio::test]
     pub async fn register_private_permissions() -> Result<()> {
-        let client = create_test_client().await?;
+        let client = create_test_client(None).await?;
         let name = XorName(rand::random());
         let tag = 15000;
         let owner = client.public_key();
@@ -338,7 +338,7 @@ mod tests {
 
     #[tokio::test]
     pub async fn register_public_permissions() -> Result<()> {
-        let client = create_test_client().await?;
+        let client = create_test_client(None).await?;
 
         let name = XorName(rand::random());
         let tag = 15000;
@@ -376,7 +376,7 @@ mod tests {
     pub async fn register_write() -> Result<()> {
         let name = XorName(rand::random());
         let tag = 10;
-        let client = create_test_client().await?;
+        let client = create_test_client(None).await?;
 
         let owner = client.public_key();
         let mut perms = BTreeMap::<User, PublicPermissions>::new();
@@ -432,7 +432,7 @@ mod tests {
     pub async fn register_owner() -> Result<()> {
         let name = XorName(rand::random());
         let tag = 10;
-        let client = create_test_client().await?;
+        let client = create_test_client(None).await?;
 
         let owner = client.public_key();
         let mut perms = BTreeMap::<PublicKey, PrivatePermissions>::new();
@@ -451,7 +451,7 @@ mod tests {
 
     #[tokio::test]
     pub async fn register_can_delete_private() -> Result<()> {
-        let mut client = create_test_client().await?;
+        let mut client = create_test_client(None).await?;
         let name = XorName(rand::random());
         let tag = 15000;
         let owner = client.public_key();
@@ -490,7 +490,7 @@ mod tests {
 
     #[tokio::test]
     pub async fn register_cannot_delete_public() -> Result<()> {
-        let client = create_test_client().await?;
+        let client = create_test_client(None).await?;
 
         let name = XorName(rand::random());
         let tag = 15000;
@@ -529,7 +529,7 @@ mod tests {
     pub async fn register_deletions_should_cost_put_price() -> Result<()> {
         let name = XorName(rand::random());
         let tag = 10;
-        let client = create_test_client().await?;
+        let client = create_test_client(None).await?;
         let owner = client.public_key();
         let perms = BTreeMap::<PublicKey, PrivatePermissions>::new();
         let address = client
