@@ -6,7 +6,6 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use crate::messaging::section_info::Error as TargetSectionError;
 use crate::types::DataAddress;
 use crate::types::PublicKey;
 use serde::{Deserialize, Serialize};
@@ -162,7 +161,4 @@ pub enum Error {
     /// The node hasn't left the section, and was not marked for relocation during reward operations
     #[error("Node is not being relocated")]
     NodeWasNotRelocated,
-    /// There was an error in the target section of a message. Probably related to section keys.
-    #[error("Target section error")]
-    TargetSection(#[from] TargetSectionError),
 }
