@@ -10,28 +10,39 @@ mod plain_message;
 mod src_authority;
 
 pub use self::{plain_message::PlainMessageUtils, src_authority::SrcAuthorityUtils};
-use crate::messaging::node::{KeyedSig, SigShare};
 use crate::messaging::{
-    node::{JoinResponse, PlainMessage, RoutingMsg, SrcAuthority, Variant},
+    node::{KeyedSig, PlainMessage, RoutingMsg, SigShare, SrcAuthority, Variant},
     Aggregation, DstLocation, MessageId,
 };
 use crate::routing::{
-    dkg::SectionSignedUtils,
     ed25519::{self, Verifier},
     error::{Error, Result},
     node::Node,
-    section::{SectionKeyShare, SectionUtils},
+    section::SectionKeyShare,
 };
+use bls::PublicKey as BlsPublicKey;
 use secured_linked_list::{error::Error as SecuredLinkedListError, SecuredLinkedList};
 use serde::Serialize;
 use std::fmt::Debug;
 use thiserror::Error;
 use xor_name::XorName;
 
+// View of a message that can be serialized for the purpose of signing.
+#[derive(Serialize)]
+pub struct SignableView<'a> {
+    // TODO: why don't we include also `src`?
+    pub dst: &'a DstLocation,
+    pub variant: &'a Variant,
+}
+
 /// Message sent over the network.
-pub trait RoutingMsgUtils {
-    /// Check the signature is valid. Only called on message receipt.
-    fn check_signature(msg: &RoutingMsg) -> Result<()>;
+pub(crate) trait RoutingMsgUtils {
+    /// Verify this message is properly signed.
+    fn check_signature(&self) -> Result<()>;
+
+    // Verify if the section chain of the SrcAuthority can be trusted
+    // based on a set of known keys.
+    fn verify_src_section_chain(&self, known_keys: &[BlsPublicKey]) -> bool;
 
     /// Creates a signed message where signature is assumed valid.
     fn new_signed(
@@ -72,65 +83,52 @@ pub trait RoutingMsgUtils {
         section_chain: SecuredLinkedList,
     ) -> Result<RoutingMsg>;
 
-    /// Verify this message is properly signed and trusted.
-    fn verify<'a, I: IntoIterator<Item = &'a bls::PublicKey>>(
-        &self,
-        trusted_keys: I,
-    ) -> Result<VerifyStatus>;
-
     /// Getter
     fn keyed_sig(&self) -> Option<KeyedSig>;
 
-    fn verify_variant<'a, I: IntoIterator<Item = &'a bls::PublicKey>>(
-        &self,
-        trusted_keys: I,
-    ) -> Result<VerifyStatus>;
-
     /// Returns an updated message with the provided Section key i.e. known to be latest.
     fn updated_with_latest_key(&mut self, section_pk: bls::PublicKey);
 }
 
 impl RoutingMsgUtils for RoutingMsg {
-    /// Check the signature is valid. Only called on message receipt.
-    fn check_signature(msg: &RoutingMsg) -> Result<()> {
-        let signed_bytes = bincode::serialize(&SignableView {
-            dst: &msg.dst,
-            variant: &msg.variant,
-        })
-        .map_err(|_| Error::InvalidMessage)?;
+    /// Verify this message is properly signed.
+    fn check_signature(&self) -> Result<()> {
+        let bytes = bincode::serialize(&self.signable_view()).map_err(|_| Error::InvalidMessage)?;
 
-        match &msg.src {
+        match &self.src {
             SrcAuthority::Node {
                 public_key,
                 signature,
                 ..
             } => {
-                if public_key.verify(&signed_bytes, signature).is_err() {
-                    error!("Failed signature: {:?}", msg);
-                    return Err(Error::CreateError(CreateError::FailedSignature));
+                if public_key.verify(&bytes, signature).is_err() {
+                    error!("Failed signature: {:?}", self);
+                    return Err(Error::FailedSignature);
                 }
             }
             SrcAuthority::BlsShare { sig_share, .. } => {
-                if !sig_share.verify(&signed_bytes) {
-                    error!("Failed signature: {:?}", msg);
-                    return Err(Error::CreateError(CreateError::FailedSignature));
-                }
-
-                if sig_share.public_key_set.public_key() != msg.section_pk {
+                // Signed chain is required for accumulation at destination.
+                if sig_share.public_key_set.public_key() != self.section_pk {
                     error!(
                         "Signed share public key doesn't match signed chain last key: {:?}",
-                        msg
+                        self
                     );
-                    return Err(Error::CreateError(CreateError::FailedSignature));
+                    return Err(Error::InvalidMessage);
+                }
+
+                if !sig_share.verify(&bytes) {
+                    error!("Failed signature: {:?}", self);
+                    return Err(Error::FailedSignature);
                 }
             }
             SrcAuthority::Section { sig, .. } => {
-                if !msg.section_pk.verify(&sig.signature, &signed_bytes) {
+                // Signed chain is required for section-src messages.
+                if !self.section_pk.verify(&sig.signature, &bytes) {
                     error!(
                         "Failed signature: {:?} (Section PK: {:?})",
-                        msg, msg.section_pk
+                        self, self.section_pk
                     );
-                    return Err(Error::CreateError(CreateError::FailedSignature));
+                    return Err(Error::FailedSignature);
                 }
             }
         }
@@ -138,6 +136,18 @@ impl RoutingMsgUtils for RoutingMsg {
         Ok(())
     }
 
+    // Verify if the section chain of the SrcAuthority can be trusted
+    // based on a set of known keys.
+    fn verify_src_section_chain(&self, known_keys: &[BlsPublicKey]) -> bool {
+        match &self.src {
+            SrcAuthority::Node { .. } => true,
+            SrcAuthority::BlsShare { section_chain, .. }
+            | SrcAuthority::Section { section_chain, .. } => {
+                section_chain.check_trust(known_keys.iter())
+            }
+        }
+    }
+
     /// Creates a signed message where signature is assumed valid.
     fn new_signed(
         src: SrcAuthority,
@@ -285,67 +295,6 @@ impl RoutingMsgUtils for RoutingMsg {
         )
     }
 
-    /// Verify this message is properly signed and trusted.
-    fn verify<'a, I>(&self, trusted_keys: I) -> Result<VerifyStatus>
-    where
-        I: IntoIterator<Item = &'a bls::PublicKey>,
-    {
-        let bytes = bincode::serialize(&SignableView {
-            dst: &self.dst,
-            variant: &self.variant,
-        })
-        .map_err(|_| Error::InvalidMessage)?;
-
-        match &self.src {
-            SrcAuthority::Node {
-                public_key,
-                signature,
-                ..
-            } => {
-                if public_key.verify(&bytes, signature).is_err() {
-                    return Err(Error::FailedSignature);
-                }
-
-                // Variant-specific verification.
-                self.verify_variant(trusted_keys)
-            }
-            SrcAuthority::BlsShare {
-                sig_share,
-                section_chain,
-                ..
-            } => {
-                // Signed chain is required for accumulation at destination.
-                if sig_share.public_key_set.public_key() != self.section_pk {
-                    return Err(Error::InvalidMessage);
-                }
-
-                if !sig_share.verify(&bytes) {
-                    return Err(Error::FailedSignature);
-                }
-
-                if section_chain.check_trust(trusted_keys) {
-                    Ok(VerifyStatus::Full)
-                } else {
-                    Ok(VerifyStatus::Unknown)
-                }
-            }
-            SrcAuthority::Section {
-                sig, section_chain, ..
-            } => {
-                // Signed chain is required for section-src messages.
-                if !self.section_pk.verify(&sig.signature, &bytes) {
-                    return Err(Error::FailedSignature);
-                }
-
-                if section_chain.check_trust(trusted_keys) {
-                    Ok(VerifyStatus::Full)
-                } else {
-                    Ok(VerifyStatus::Unknown)
-                }
-            }
-        }
-    }
-
     /// Getter
     fn keyed_sig(&self) -> Option<KeyedSig> {
         if let SrcAuthority::Section { sig, .. } = &self.src {
@@ -355,81 +304,11 @@ impl RoutingMsgUtils for RoutingMsg {
         }
     }
 
-    fn verify_variant<'a, I>(&self, trusted_keys: I) -> Result<VerifyStatus>
-    where
-        I: IntoIterator<Item = &'a bls::PublicKey>,
-    {
-        let proof_chain = match &self.variant {
-            Variant::JoinResponse(resp) => {
-                if let JoinResponse::Approval {
-                    ref section_auth,
-                    ref node_state,
-                    ref section_chain,
-                    ..
-                } = **resp
-                {
-                    if !section_auth.verify(section_chain) {
-                        return Err(Error::InvalidMessage);
-                    }
-
-                    if !node_state.verify(section_chain) {
-                        return Err(Error::InvalidMessage);
-                    }
-
-                    section_chain
-                } else {
-                    return Ok(VerifyStatus::Full);
-                }
-            }
-            Variant::SectionKnowledge {
-                src_info: (_, ref chain),
-                ..
-            } => chain,
-            Variant::Sync { section, .. } => section.chain(),
-            _ => return Ok(VerifyStatus::Full),
-        };
-
-        if proof_chain.check_trust(trusted_keys) {
-            Ok(VerifyStatus::Full)
-        } else {
-            Ok(VerifyStatus::Unknown)
-        }
-    }
-
     fn updated_with_latest_key(&mut self, section_pk: bls::PublicKey) {
         self.section_pk = section_pk
     }
 }
 
-#[derive(Eq, PartialEq, Debug)]
-pub enum VerifyStatus {
-    // The message has been fully verified.
-    Full,
-    // The message trust and integrity cannot be verified because it's signed is not trusted by us,
-    // even though it is valid. The message should be relayed to other nodes who might be able to
-    // verify it.
-    Unknown,
-}
-
-/// Status of an incomming message.
-#[derive(Eq, PartialEq)]
-pub enum MessageStatus {
-    /// Message is useful and should be handled.
-    Useful,
-    /// Message is useless and should be discarded.
-    Useless,
-    /// Message trust can't be established.
-    Untrusted,
-}
-
-#[derive(Debug, Error)]
-pub enum CreateError {
-    #[error("signature check failed")]
-    FailedSignature,
-    #[error("public key mismatch")]
-    PublicKeyMismatch,
-}
-
 /// Error returned from `RoutingMsg::extend_proof_chain`.
 #[derive(Debug, Error)]
 pub enum ExtendSignedChainError {
@@ -437,14 +316,4 @@ pub enum ExtendSignedChainError {
     NoSignedChain,
     #[error("failed to extend signed chain: {}", .0)]
     Extend(#[from] SecuredLinkedListError),
-    #[error("failed to re-create message: {}", .0)]
-    Create(#[from] CreateError),
-}
-
-// View of a message that can be serialized for the purpose of signing.
-#[derive(Serialize)]
-pub struct SignableView<'a> {
-    // TODO: why don't we include also `src`?
-    pub dst: &'a DstLocation,
-    pub variant: &'a Variant,
 }
